@@ -81,7 +81,7 @@ inline static void do_checksum(dbinfo *dbinf, const char *fname)
     utb.actime	 = dbinf->stat.st_atime;
     utb.modtime	 = dbinf->stat.st_mtime;
     if (utime(fname, &utb) == -1)
-      warn(PROGNAME, __FUNCTION__,
+      warn(__FUNCTION__,
 	  "Warning: resetting access time for file (%s): %s",
 	  fname, strerror(errno));
 }
@@ -176,7 +176,7 @@ static void report_differences(options *opts, fileinfo *currinf,
 
     if (S_ISREG(currinf->dbinf.stat.st_mode)) {	/* if it's a regular file */
       if (knownsiz != sizeof(dbinfo)) /* maybe known has no checksum */
-	printf("%s changed to regular file\n", path);
+	printf("changed: %s became regular file\n", path);
       else if (flags & RULE_SUM) {
 	if (! currinf->did_sum) {
 	  do_checksum(&currinf->dbinf, path);
@@ -267,7 +267,9 @@ wft_ret_t process_file(const char *path, const struct stat *sb, void *data)
 
     /* see whether checkset includes boolean to ignore the file */
     if (cset && (CHECKSET_GETIGNORE(cset))) { 
+#ifdef	DEBUG
       printf("debug: ignoring file (%s)\n", p);
+#endif
       free(pathcopy);
       return WFT_PRUNE;
     }
@@ -283,8 +285,12 @@ wft_ret_t process_file(const char *path, const struct stat *sb, void *data)
     free(pathcopy);
 
     /* see whether the nochildren boolean is true in this checkset */
-    if (cset && (CHECKSET_GETNOCHILD(cset)))
+    if (cset && (CHECKSET_GETNOCHILD(cset))) {
+#ifdef	DEBUG
+      printf("debug: no children for file (%s)\n", path);
+#endif
       return WFT_PRUNE;
+    }
 
     return WFT_PROCEED;
 }
