@@ -54,13 +54,13 @@ inline static void chomp(char *chp)
 
 void options_announce(options *o)
 {
-    printf("---- %s -----------------\n", INTEGRIT_VERSION);
-    printf("%36s : %s\n", "conf file", o->conffile);
-    printf("%36s : %s\n", "known db", o->knowndbname);
-    printf("%36s : %s\n", "current db", o->currdbname);
-    printf("%36s : %s\n", "root", o->root);
-    printf("%36s : %s\n", "do check", o->do_check ? "yes" : "no");
-    printf("%36s : %s\n", "do update", o->do_update ? "yes" : "no");
+    printf(PROGNAME ": ---- %s -----------------\n", INTEGRIT_VERSION);
+    printf(PROGNAME ": %27s : %s\n", "conf file", o->conffile);
+    printf(PROGNAME ": %27s : %s\n", "known db", o->knowndbname);
+    printf(PROGNAME ": %27s : %s\n", "current db", o->currdbname);
+    printf(PROGNAME ": %27s : %s\n", "root", o->root);
+    printf(PROGNAME ": %27s : %s\n", "do check", o->do_check ? "yes" : "no");
+    printf(PROGNAME ": %27s : %s\n", "do update", o->do_update ? "yes" : "no");
 }
 
 void options_init(options *o)
@@ -221,9 +221,11 @@ inline static void do_rule(options *o, char *buf)
     strcpy(CHECKSET_SWITCHSTART(cset), buf);
     
     chomp(namebuf);
+#ifdef	DEBUG
     printf("debug: path (%s) checkset (", namebuf);
     checkset_show(stdout, cset);	/* debug */
     fputs(")\n", stdout);
+#endif
     
     options_add_checkset(o, namebuf, namebuf_chars, cset);
 }
